@@ -1,13 +1,6 @@
 #!/usr/bin/env python3
 
-import sys
-import logging
-import argparse
-import locale
-import time
-import pygoodwe
-from datetime import datetime
-from astral import Astral
+""" terrible script """
 
 __version__ = "0.0.1"
 __author__ = "James Hodgkinson"
@@ -15,7 +8,6 @@ __copyright__ = "Copyright 2019-, James Hodgkinson"
 __license__ = "MIT"
 __email__ = "james@terminaloutcomes.com"
 
-last_eday_kwh = 0
 
 if __name__ == "__main__":
     print("Sorry, nothing to see here.")
